==> cdktf_cdktf_provider_azurerm-0.8.13-py3-none-any.whl: package/lib/resource-group-policy-remediation.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ResourceGroupPolicyRemediationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#id ResourceGroupPolicyRemediation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#location_filters ResourceGroupPolicyRemediation#location_filters}
    */
    readonly locationFilters?: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#name ResourceGroupPolicyRemediation#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#policy_assignment_id ResourceGroupPolicyRemediation#policy_assignment_id}
    */
    readonly policyAssignmentId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#policy_definition_id ResourceGroupPolicyRemediation#policy_definition_id}
    */
    readonly policyDefinitionId?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#resource_discovery_mode ResourceGroupPolicyRemediation#resource_discovery_mode}
    */
    readonly resourceDiscoveryMode?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#resource_group_id ResourceGroupPolicyRemediation#resource_group_id}
    */
    readonly resourceGroupId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#timeouts ResourceGroupPolicyRemediation#timeouts}
    */
    readonly timeouts?: ResourceGroupPolicyRemediationTimeouts;
}
export interface ResourceGroupPolicyRemediationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#create ResourceGroupPolicyRemediation#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#delete ResourceGroupPolicyRemediation#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#read ResourceGroupPolicyRemediation#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#update ResourceGroupPolicyRemediation#update}
    */
    readonly update?: string;
}
export declare function resourceGroupPolicyRemediationTimeoutsToTerraform(struct?: ResourceGroupPolicyRemediationTimeoutsOutputReference | ResourceGroupPolicyRemediationTimeouts | cdktf.IResolvable): any;
export declare class ResourceGroupPolicyRemediationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ResourceGroupPolicyRemediationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ResourceGroupPolicyRemediationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation azurerm_resource_group_policy_remediation}
*/
export declare class ResourceGroupPolicyRemediation extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_resource_group_policy_remediation";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation azurerm_resource_group_policy_remediation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ResourceGroupPolicyRemediationConfig
    */
    constructor(scope: Construct, id: string, config: ResourceGroupPolicyRemediationConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _locationFilters?;
    get locationFilters(): string[];
    set locationFilters(value: string[]);
    resetLocationFilters(): void;
    get locationFiltersInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _policyAssignmentId?;
    get policyAssignmentId(): string;
    set policyAssignmentId(value: string);
    get policyAssignmentIdInput(): string | undefined;
    private _policyDefinitionId?;
    get policyDefinitionId(): string;
    set policyDefinitionId(value: string);
    resetPolicyDefinitionId(): void;
    get policyDefinitionIdInput(): string | undefined;
    private _resourceDiscoveryMode?;
    get resourceDiscoveryMode(): string;
    set resourceDiscoveryMode(value: string);
    resetResourceDiscoveryMode(): void;
    get resourceDiscoveryModeInput(): string | undefined;
    private _resourceGroupId?;
    get resourceGroupId(): string;
    set resourceGroupId(value: string);
    get resourceGroupIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): ResourceGroupPolicyRemediationTimeoutsOutputReference;
    putTimeouts(value: ResourceGroupPolicyRemediationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ResourceGroupPolicyRemediationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-2.0.17-py3-none-any.whl: package/lib/resource-group-policy-remediation.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ResourceGroupPolicyRemediationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#failure_percentage ResourceGroupPolicyRemediation#failure_percentage}
    */
    readonly failurePercentage?: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#id ResourceGroupPolicyRemediation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#location_filters ResourceGroupPolicyRemediation#location_filters}
    */
    readonly locationFilters?: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#name ResourceGroupPolicyRemediation#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#parallel_deployments ResourceGroupPolicyRemediation#parallel_deployments}
    */
    readonly parallelDeployments?: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#policy_assignment_id ResourceGroupPolicyRemediation#policy_assignment_id}
    */
    readonly policyAssignmentId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#policy_definition_id ResourceGroupPolicyRemediation#policy_definition_id}
    */
    readonly policyDefinitionId?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#policy_definition_reference_id ResourceGroupPolicyRemediation#policy_definition_reference_id}
    */
    readonly policyDefinitionReferenceId?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#resource_count ResourceGroupPolicyRemediation#resource_count}
    */
    readonly resourceCount?: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#resource_discovery_mode ResourceGroupPolicyRemediation#resource_discovery_mode}
    */
    readonly resourceDiscoveryMode?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#resource_group_id ResourceGroupPolicyRemediation#resource_group_id}
    */
    readonly resourceGroupId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#timeouts ResourceGroupPolicyRemediation#timeouts}
    */
    readonly timeouts?: ResourceGroupPolicyRemediationTimeouts;
}
export interface ResourceGroupPolicyRemediationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#create ResourceGroupPolicyRemediation#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#delete ResourceGroupPolicyRemediation#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#read ResourceGroupPolicyRemediation#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation#update ResourceGroupPolicyRemediation#update}
    */
    readonly update?: string;
}
export declare function resourceGroupPolicyRemediationTimeoutsToTerraform(struct?: ResourceGroupPolicyRemediationTimeoutsOutputReference | ResourceGroupPolicyRemediationTimeouts | cdktf.IResolvable): any;
export declare class ResourceGroupPolicyRemediationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ResourceGroupPolicyRemediationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ResourceGroupPolicyRemediationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation azurerm_resource_group_policy_remediation}
*/
export declare class ResourceGroupPolicyRemediation extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_resource_group_policy_remediation";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/resource_group_policy_remediation azurerm_resource_group_policy_remediation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ResourceGroupPolicyRemediationConfig
    */
    constructor(scope: Construct, id: string, config: ResourceGroupPolicyRemediationConfig);
    private _failurePercentage?;
    get failurePercentage(): number;
    set failurePercentage(value: number);
    resetFailurePercentage(): void;
    get failurePercentageInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _locationFilters?;
    get locationFilters(): string[];
    set locationFilters(value: string[]);
    resetLocationFilters(): void;
    get locationFiltersInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _parallelDeployments?;
    get parallelDeployments(): number;
    set parallelDeployments(value: number);
    resetParallelDeployments(): void;
    get parallelDeploymentsInput(): number | undefined;
    private _policyAssignmentId?;
    get policyAssignmentId(): string;
    set policyAssignmentId(value: string);
    get policyAssignmentIdInput(): string | undefined;
    private _policyDefinitionId?;
    get policyDefinitionId(): string;
    set policyDefinitionId(value: string);
    resetPolicyDefinitionId(): void;
    get policyDefinitionIdInput(): string | undefined;
    private _policyDefinitionReferenceId?;
    get policyDefinitionReferenceId(): string;
    set policyDefinitionReferenceId(value: string);
    resetPolicyDefinitionReferenceId(): void;
    get policyDefinitionReferenceIdInput(): string | undefined;
    private _resourceCount?;
    get resourceCount(): number;
    set resourceCount(value: number);
    resetResourceCount(): void;
    get resourceCountInput(): number | undefined;
    private _resourceDiscoveryMode?;
    get resourceDiscoveryMode(): string;
    set resourceDiscoveryMode(value: string);
    resetResourceDiscoveryMode(): void;
    get resourceDiscoveryModeInput(): string | undefined;
    private _resourceGroupId?;
    get resourceGroupId(): string;
    set resourceGroupId(value: string);
    get resourceGroupIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): ResourceGroupPolicyRemediationTimeoutsOutputReference;
    putTimeouts(value: ResourceGroupPolicyRemediationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ResourceGroupPolicyRemediationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
